******************
:mod:`gdsCAD.core`
******************

.. automodule:: gdsCAD.core

Inheritance Diagram
===================

.. inheritance-diagram:: gdsCAD.core
    :parts: 2


Class and Function Summary
==========================
.. currentmodule:: gdsCAD.core

.. autosummary::
    Layout
    Cell
    Boundary
    Path
    Elements
    CellReference
    CellArray
    GdsImport


Module Definition
=================
.. automodule:: gdsCAD.core
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:
 